from django.core.management import BaseCommand

from django_email_foundation.api import DjangoEmailFoundation


class Command(BaseCommand):
    help = 'Install the node required packages.'

    def handle(self, *args, **options):
        engine = DjangoEmailFoundation()
        success = engine.install_required_packages
        if not success:
            self.stdout.write(self.style.ERROR(
                'Oops! Something went wrong... :('))



from typing import List

from django.core.management import BaseCommand

from django_email_foundation.api import DjangoEmailFoundation


class Command(BaseCommand):
    help = 'Run a service for watch and compile the email templates'

    def handle(self, *args, **options):
        engine = DjangoEmailFoundation()
        errors = engine.perform_checks()
        if errors:
            self._show_errors(errors)
            return

        self.stdout.write(self.style.SUCCESS('Oh, yes! Punchi, punchi! Lets go!'))

        engine = DjangoEmailFoundation()
        engine.run_watch()

    def _show_errors(self, errors: List[str]):
        self.stdout.write(self.style.ERROR('Oops! Something went wrong...'))
        for error in errors:
            self.stdout.write(self.style.ERROR('  - {}'.format(error)))
        self.stdout.write('\n')



import re

from setuptools import setup

package = open('django_email_foundation/__init__.py').read()
metadata = dict(re.findall("__([A-Z]+)__ = '([^']+)'", package))
__VERSION__ = metadata['VERSION']

with open('docs/index.rst') as docs_index:
    long_description = docs_index.read()

# Requirements
INSTALL_REQUIRES = (
)

TEST_REQUIREMENTS = (
    'pytest==4.3.1',
    'pytest-flake8==1.0.4',
)

setup(
    name='django-email-foundation',
    version=__VERSION__,
    description='django-email-foundation is a Django package for help you to create emails using '
                'the "zurb foundation" technologies',
    long_description=long_description,
    author='Francesc Arpí',
    author_email='francesc.arpi@gmail.com',
    url='http://github.com/APSL/django-email-foundation',
    install_requires=INSTALL_REQUIRES,
    packages=[
        'django_email_foundation',
    ],
    include_package_data=True,
    # tests
    tests_require=TEST_REQUIREMENTS,
    test_suite='pytest',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Framework :: Django',
        'Framework :: Django :: 2.1',
    ]
)



import os

from django.conf import settings

# Define witch installer application you want to use, "yarn" or "npm".
DEF_NPM_OR_YARN = getattr(settings, 'DEF_NPM_OR_YARN', 'yarn')

# If the installer is "npm", use the "install" command.
DEF_INSTALL_COMMANDS = {
    'npm': 'install',
    'yarn': 'add',
}

DEF_NPM_YARN_INSTALL_COMMAND = DEF_INSTALL_COMMANDS[DEF_NPM_OR_YARN]

# Define where to install the node modules packages (the node_modules folder). By default is at project root.
DEF_NODE_MODULES_PATH = getattr(settings, 'DEF_NODE_MODULES_PATH', os.getcwd())

# A list with a node modules required packages
DEF_NODE_PACKAGES_REQUIRED = (
    'gulp@4.0.0',
    'panini@1.3.0',
    'inky@1.3.6',
    'gulp-open@3.0.1',
    'gulp-debug@4.0.0',
    'gulp-load-plugins@1.5.0',
    'gulp-sass@2.3.2',
    'gulp-inline-css@3.3.1',
    'gulp-uncss@1.0.6',
    'node-sass@4.9.3',
    'gulp-imagemin@2.4.0',
    'siphon-media-query@1.0.0',
    'lazypipe@1.0.2',
    'gulp-htmlmin@1.3.0',
    'gulp-replace@0.5.4',
)

# Path for email templates. This settings is required for start run the email builder.
DEF_TEMPLATES_SOURCE_PATH = getattr(settings, 'DEF_TEMPLATES_SOURCE_PATH', None)

# Path where store the compiles templates
DEF_TEMPLATES_TARGET_PATH = getattr(settings, 'DEF_TEMPLATES_TARGET_PATH', None)

# Path where move the static files (images)
DEF_STATIC_TARGET_PATH = getattr(settings, 'DEF_STATIC_TARGET_PATH', None)

# List of ignored templates.
DEF_IGNORE_FILES = getattr(settings, 'DEF_IGNORE_FILES', (
    'subject.html',
    'body.txt',
))

# The default runserver host for preview
DEF_RUNSERVER_HOST = getattr(settings, 'DEF_RUNSERVER_HOST', 'http://localhost:8000')
